==> calamares-settings-solydxk_4.12%2Br13.tar.xz: source/ts/calamares-solydxk_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Gracias por elegir SolydXK.&lt;/h3&gt;&lt;br /&gt;Ha elegido una distribución de Linux que es:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Segura y estable&lt;/li&gt;&lt;li&gt;Rápida y eficaz&lt;/li&gt;&lt;li&gt;Listo para su escritorio&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Disfrute de esta nueva edición y gracias por elegir SolydXK.&lt;br /&gt;&lt;br /&gt;La instalación dura unos 15-30 minutos, dependiendo de las configuraciones.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Asentados sobre los hombros de Gigantes&lt;/h3&gt;&lt;br /&gt;SolydXK es una distribución basada en Debian GNU/Linux siendo totalmente compatible con Debian.&lt;br /&gt;&lt;br /&gt;SolydXK utiliza o bien el escritorio ligero Xfce para SolydX, o bien el altamente configurable e increíblemente atractivo escritorio KDE para SolydK.&lt;br /&gt;&lt;br /&gt;Nuestras propias innovaciones, más el rápido desarrollo y la enorme selección de paquetes de Debian hacen de SolydXK uno de los sistemas operativos de escritorio más atractivos disponibles para los usuarios.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Listo para usarse&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird y LibreOffice vienen pre-instalados en SolydXK, de modo que puede comenzar inmediatamente a utilizar el escritorio e Internet.&lt;br /&gt;&lt;br /&gt;A diferencia de otras distribuciones de Linux, SolydXK también está listo para reproducir su música, videos de internet y más.&lt;br /&gt;&lt;br /&gt;Una gran variedad de software puede ser instalado con un simple clik del ratón.&lt;br /&gt;&lt;br /&gt;SolydXK es compatible con los formatos de archivo más populares como: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg y muchos más.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Las Herramientas de oficina están listas para usar inmediatamente después de completar la instalación&lt;/h3&gt;&lt;br /&gt;LibreOffice,una potente colección de herramientas de oficina, viene preinstalada en SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice es muy fácil de aprender y usar.&lt;br /&gt;&lt;br /&gt;Puede utilizarse para crear cartas, presentaciones y hojas de cálculo, así como diagramas y bases de datos.&lt;br /&gt;&lt;br /&gt;LibreOffice utiliza el formato OpenDocument standard y es compatible con documentos de otras aplicaciones de oficina populares incluyendo WordPerfect y Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.&lt;br /&gt;&lt;br /&gt;SolydXK can detect other operating systems and install itself beside them.You can choose which operating system to launch when you start the computer.</source>
        <translation>&lt;h3&gt;Una alternativa a los sistemas operativos más conocidos&lt;/h3&gt;&lt;br /&gt;SolydXK es potente, configurable y fácil de usar.&lt;br /&gt;&lt;br /&gt;SolydXK es seguro y estable. Al contrario que otros sistemas operativos, no es susceptible de virus y spyware, no sufre de fragmentación de discos, y no tiene un registro que necesite una limpieza periódica.&lt;br /&gt;&lt;br /&gt;SolydXK es capaz de detectar otros sistemas operativos e instalarse junto a ellos. Puede elegir qué sistema operativo arrancar cuando encienda su equipo.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="143"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Actualizaciones seguras&lt;/h3&gt;&lt;br /&gt;Algunos sistemas operativos hacen que mantenerlos al día sea más complejo de lo que realmente necesita ser. SolydXK considera que las actualizaciones deben ser rápidas y fáciles, y su vez no interferir en la productividad.&lt;br /&gt;&lt;br /&gt;El gestor de actualizaciones reside discretamente en la bandeja del sistema y le avisa cuando hay actualizaciones disponibles. No necesita aplicar las actualizaciones cuando no lo desea. El gestor de actualizaciones no le interrumpirá o molestará de ninguna manera.&lt;br /&gt;&lt;br /&gt;Todos los archivos actualizados son mantenidos y minuciosamente comprobados por desarrolladores y mantenedores de confianza.&lt;br /&gt;&lt;br /&gt;Todos los archivos están almacenados en repositorios especiales y seguros para su uso.&lt;br /&gt;&lt;br /&gt;El repositorio de seguridad se sincroniza diariamente.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="165"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Una gran comunidad&lt;/h3&gt;&lt;br /&gt;Los usuarios de SolydXK están encantados de compartir su pasión y entusiasmo y están ansiosos por ayudar. No dude en hacer preguntas en los foros o en involucrarse en la comunidad.&lt;br /&gt;&lt;br /&gt;Envíenos sus comentarios y cuéntenos su experiencia. Escucharemos sus ideas y las utilizaremos para mejorar SolydXK.</translation>
    </message>
</context>
</TS>

==> calamares-settings-solydxk_4.27%2Br13.tar.xz: source/ts/calamares-solydxk_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Gracias por elegir SolydXK.&lt;/h3&gt;&lt;br /&gt;Ha elegido una distribución de Linux que es:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Segura y estable&lt;/li&gt;&lt;li&gt;Rápida y eficaz&lt;/li&gt;&lt;li&gt;Listo para su escritorio&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Disfrute de esta nueva edición y gracias por elegir SolydXK.&lt;br /&gt;&lt;br /&gt;La instalación dura unos 15-30 minutos, dependiendo de las configuraciones.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Asentados sobre los hombros de Gigantes&lt;/h3&gt;&lt;br /&gt;SolydXK es una distribución basada en Debian GNU/Linux siendo totalmente compatible con Debian.&lt;br /&gt;&lt;br /&gt;SolydXK utiliza o bien el escritorio ligero Xfce para SolydX, o bien el altamente configurable e increíblemente atractivo escritorio KDE para SolydK.&lt;br /&gt;&lt;br /&gt;Nuestras propias innovaciones, más el rápido desarrollo y la enorme selección de paquetes de Debian hacen de SolydXK uno de los sistemas operativos de escritorio más atractivos disponibles para los usuarios.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Listo para usarse&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird y LibreOffice vienen pre-instalados en SolydXK, de modo que puede comenzar inmediatamente a utilizar el escritorio e Internet.&lt;br /&gt;&lt;br /&gt;A diferencia de otras distribuciones de Linux, SolydXK también está listo para reproducir su música, videos de internet y más.&lt;br /&gt;&lt;br /&gt;Una gran variedad de software puede ser instalado con un simple clik del ratón.&lt;br /&gt;&lt;br /&gt;SolydXK es compatible con los formatos de archivo más populares como: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg y muchos más.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Las Herramientas de oficina están listas para usar inmediatamente después de completar la instalación&lt;/h3&gt;&lt;br /&gt;LibreOffice,una potente colección de herramientas de oficina, viene preinstalada en SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice es muy fácil de aprender y usar.&lt;br /&gt;&lt;br /&gt;Puede utilizarse para crear cartas, presentaciones y hojas de cálculo, así como diagramas y bases de datos.&lt;br /&gt;&lt;br /&gt;LibreOffice utiliza el formato OpenDocument standard y es compatible con documentos de otras aplicaciones de oficina populares incluyendo WordPerfect y Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.</source>
        <translation>&lt;h3&gt;Una alternativa a los sistemas operativos más conocidos&lt;/h3&gt;&lt;br /&gt;SolydXK es potente, configurable y fácil de usar.&lt;br /&gt;&lt;br /&gt;SolydXK es seguro y estable. Al contrario que otros sistemas operativos, no es susceptible de virus y spyware, no sufre de fragmentación de discos, y no tiene un registro que necesite una limpieza periódica.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="142"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Actualizaciones seguras&lt;/h3&gt;&lt;br /&gt;Algunos sistemas operativos hacen que mantenerlos al día sea más complejo de lo que realmente necesita ser. SolydXK considera que las actualizaciones deben ser rápidas y fáciles, y su vez no interferir en la productividad.&lt;br /&gt;&lt;br /&gt;El gestor de actualizaciones reside discretamente en la bandeja del sistema y le avisa cuando hay actualizaciones disponibles. No necesita aplicar las actualizaciones cuando no lo desea. El gestor de actualizaciones no le interrumpirá o molestará de ninguna manera.&lt;br /&gt;&lt;br /&gt;Todos los archivos actualizados son mantenidos y minuciosamente comprobados por desarrolladores y mantenedores de confianza.&lt;br /&gt;&lt;br /&gt;Todos los archivos están almacenados en repositorios especiales y seguros para su uso.&lt;br /&gt;&lt;br /&gt;El repositorio de seguridad se sincroniza diariamente.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="164"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Una gran comunidad&lt;/h3&gt;&lt;br /&gt;Los usuarios de SolydXK están encantados de compartir su pasión y entusiasmo y están ansiosos por ayudar. No dude en hacer preguntas en los foros o en involucrarse en la comunidad.&lt;br /&gt;&lt;br /&gt;Envíenos sus comentarios y cuéntenos su experiencia. Escucharemos sus ideas y las utilizaremos para mejorar SolydXK.</translation>
    </message>
</context>
</TS>
